import numpy as np
import matplotlib.pyplot as plt
import scipy.constants as scc
import scipy.optimize as opt
import scipy.signal as sig

date = '2015-08-07'
start = '09:06:00'
stop = '10:06:00'

# 1 second trends
_, tidalx = np.loadtxt('tidalx.txt', unpack=1)
_, tidaly = np.loadtxt('tidaly.txt', unpack=1)
_, imcpwr = np.loadtxt('imcpwr.txt', unpack=1)
tidalx = tidalx[2500:4750]
tidaly = tidaly[2500:4750]
imcpwr = imcpwr[2500:4750]

tidalx /= 1000
tidaly /= 1000

tt = np.arange(len(tidalx))
tbreak = 1000

px = np.polyfit(tt[:tbreak], tidalx[:tbreak], 1)
py = np.polyfit(tt[:tbreak], tidaly[:tbreak], 1)
tidalxdetrend = tidalx-(px[0]*tt+px[1])
tidalydetrend = tidaly-(py[0]*tt+py[1])

x0 = np.mean(tidalxdetrend[:1000])
y0 = np.mean(tidalydetrend[:1000])
x1 = np.mean(tidalxdetrend[1500:])
y1 = np.mean(tidalydetrend[1500:])
P0 = np.mean(imcpwr[:1000])
P1 = np.mean(imcpwr[1500:])

dx = x1-x0
dy = y1-y0
print('X arm displacement: {} um'.format(dx))
print('Y arm displacement: {} um'.format(dy))
dz = (dx+dy)/2
compl = 2.6e-3 # m/N
dP = scc.c * dz*1e-6 / (4*compl)
Prat = P1/P0
Pest = dP/(1-1/Prat)
print('Starting power [IMC est.]: {} W'.format(P0))
print('Starting power [IMC est.]: {} W'.format(P1))
print('Measured power ratio: {}'.format(Prat))
print('Estimated power change: {} kW'.format(dP/1e3))
print('Estimated power: {} kW'.format(Pest/1e3))



plt.clf()
plt.plot(tt, tidalx, 'b-', label='X')
plt.plot(tt, tidaly, 'r-', label='Y')
plt.plot(tt, px[0]*tt+px[1], 'b--', label='X trend')
plt.plot(tt, py[0]*tt+py[1], 'r--', label='Y trend')
plt.xlabel('Time [s]')
plt.ylabel(r'Length drive [$\mu$m]')
plt.title('Tidal drive to end-station HEPIs when powering up')
plt.legend(loc='upper left')
plt.tight_layout()
plt.savefig('HepiDrives.pdf')

plt.clf()
plt.plot(tt, tidalxdetrend, 'b', label='X')
plt.plot(tt, tidalydetrend, 'r', label='Y')
plt.xlabel('Time [s]')
plt.ylabel(r'Length drive [$\mu$m]')
plt.title('Tidal drive (detrended) to end-station HEPIs when powering up')
plt.legend()
plt.tight_layout()
plt.savefig('HepiDrivesDetrended.pdf')
